@@ -21,33 +21,23 @@ import (
 	"sort"
 	"testing"
 
-	"google.golang.org/protobuf/types/known/anypb"
-
-	"github.com/golang/protobuf/ptypes/wrappers"
-
-	"github.com/google/go-cmp/cmp/cmpopts"
-
-	"knative.dev/net-kourier/pkg/config"
-
-	"knative.dev/networking/pkg/apis/networking/v1alpha1"
-
-	"go.uber.org/zap"
-
-	"gotest.tools/assert"
-
 	v2 "github.com/envoyproxy/go-control-plane/envoy/api/v2"
 	route "github.com/envoyproxy/go-control-plane/envoy/api/v2/route"
-	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	kubeclient "k8s.io/client-go/kubernetes"
+	"github.com/envoyproxy/go-control-plane/pkg/cache"
+	"github.com/golang/protobuf/ptypes/wrappers"
+	"github.com/google/go-cmp/cmp/cmpopts"
+	"google.golang.org/protobuf/types/known/anypb"
+	"gotest.tools/v3/assert"
+	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/kubernetes/fake"
+	"knative.dev/net-kourier/pkg/config"
 )
 
 func TestDeleteIngressInfo(t *testing.T) {
-	logger := zap.S()
 	kubeClient := fake.Clientset{}
 	ctx := context.Background()
 
-	caches, err := NewCaches(ctx, logger, &kubeClient, false, nil)
+	caches, err := NewCaches(ctx, &kubeClient, false)
 	if err != nil {
 		t.Fail()
 	}
@@ -61,10 +51,8 @@ func TestDeleteIngressInfo(t *testing.T) {
 		firstIngressName,
 		firstIngressNamespace,
 		"cluster_for_ingress_1",
-		"route_for_ingress_1",
 		"internal_host_for_ingress_1",
 		"external_host_for_ingress_1",
-		&kubeClient,
 	)
 
 	// Add info for a different ingress
@@ -76,24 +64,18 @@ func TestDeleteIngressInfo(t *testing.T) {
 		secondIngressName,
 		secondIngressNamespace,
 		"cluster_for_ingress_2",
-		"route_for_ingress_2",
 		"internal_host_for_ingress_2",
 		"external_host_for_ingress_2",
-		&kubeClient,
 	)
 
 	// Delete the first ingress
-	_ = caches.DeleteIngressInfo(ctx, firstIngressName, firstIngressNamespace, &kubeClient)
+	_ = caches.DeleteIngressInfo(ctx, firstIngressName, firstIngressNamespace)
 
 	// Check that the listeners only have the virtual hosts of the second
 	// ingress.
 	// Note: Apart from the vHosts that were added explicitly, there's also
 	// the one used to verify the snapshot version.
-	vHostsNames, err := getVHostsNames(caches.routeConfig)
-
-	if err != nil {
-		t.Fail()
-	}
+	vHostsNames := getVHostsNames(caches.routeConfig)
 
 	sort.Strings(vHostsNames)
 
@@ -110,11 +92,10 @@ func TestDeleteIngressInfo(t *testing.T) {
 func TestDeleteIngressInfoWhenDoesNotExist(t *testing.T) {
 	// If the ingress does not exist, nothing should be deleted from the caches
 	// instance.
-	logger := zap.S()
 	kubeClient := fake.Clientset{}
 	ctx := context.Background()
 
-	caches, err := NewCaches(ctx, logger, &kubeClient, false, nil)
+	caches, err := NewCaches(ctx, &kubeClient, false)
 	if err != nil {
 		t.Fail()
 	}
@@ -128,10 +109,8 @@ func TestDeleteIngressInfoWhenDoesNotExist(t *testing.T) {
 		firstIngressName,
 		firstIngressNamespace,
 		"cluster_for_ingress_1",
-		"route_for_ingress_1",
 		"internal_host_for_ingress_1",
 		"external_host_for_ingress_1",
-		&kubeClient,
 	)
 
 	snapshotBeforeDelete, err := caches.ToEnvoySnapshot()
@@ -139,11 +118,11 @@ func TestDeleteIngressInfoWhenDoesNotExist(t *testing.T) {
 		t.FailNow()
 	}
 
-	clustersBeforeDelete := snapshotBeforeDelete.Clusters.Items
-	routesBeforeDelete := snapshotBeforeDelete.Routes.Items
-	listenersBeforeDelete := snapshotBeforeDelete.Listeners.Items
+	clustersBeforeDelete := snapshotBeforeDelete.GetResources(cache.ClusterType)
+	routesBeforeDelete := snapshotBeforeDelete.GetResources(cache.RouteType)
+	listenersBeforeDelete := snapshotBeforeDelete.GetResources(cache.ListenerType)
 
-	err = caches.DeleteIngressInfo(ctx, "non_existing_name", "non_existing_namespace", &kubeClient)
+	err = caches.DeleteIngressInfo(ctx, "non_existing_name", "non_existing_namespace")
 	if err != nil {
 		t.FailNow()
 	}
@@ -153,9 +132,9 @@ func TestDeleteIngressInfoWhenDoesNotExist(t *testing.T) {
 		t.FailNow()
 	}
 
-	clustersAfterDelete := snapshotAfterDelete.Clusters.Items
-	routesAfterDelete := snapshotAfterDelete.Routes.Items
-	listenersAfterDelete := snapshotAfterDelete.Listeners.Items
+	clustersAfterDelete := snapshotAfterDelete.GetResources(cache.ClusterType)
+	routesAfterDelete := snapshotAfterDelete.GetResources(cache.RouteType)
+	listenersAfterDelete := snapshotAfterDelete.GetResources(cache.ListenerType)
 
 	// This is a temporary workaround. Remove when we delete the route with a
 	// randomly generated name in status_vhost.go
@@ -181,37 +160,28 @@ func createTestDataForIngress(
 	ingressName string,
 	ingressNamespace string,
 	clusterName string,
-	routeName string,
 	internalVHostName string,
-	externalVHostName string,
-	kubeClient kubeclient.Interface) {
+	externalVHostName string) {
 
-	translatedIngress := translatedIngress{
-		ingressName:          ingressName,
-		ingressNamespace:     ingressNamespace,
-		routes:               []*route.Route{{Name: routeName}},
+	translatedIngress := &translatedIngress{
+		name: types.NamespacedName{
+			Namespace: ingressNamespace,
+			Name:      ingressName,
+		},
 		clusters:             []*v2.Cluster{{Name: clusterName}},
 		externalVirtualHosts: []*route.VirtualHost{{Name: externalVHostName, Domains: []string{externalVHostName}}},
 		internalVirtualHosts: []*route.VirtualHost{{Name: internalVHostName, Domains: []string{internalVHostName}}},
 	}
 
-	_ = caches.addTranslatedIngress(&v1alpha1.Ingress{
-		ObjectMeta: v1.ObjectMeta{
-			Name:      ingressName,
-			Namespace: ingressNamespace,
-		},
-	}, &translatedIngress)
-
-	caches.addStatusVirtualHost()
-	_ = caches.setListeners(ctx, kubeClient)
+	_ = caches.addTranslatedIngress(translatedIngress)
+	_ = caches.setListeners(ctx)
 }
 
 func TestValidateIngress(t *testing.T) {
-	logger := zap.S()
 	kubeClient := fake.Clientset{}
 	ctx := context.Background()
 
-	caches, err := NewCaches(ctx, logger, &kubeClient, false, nil)
+	caches, err := NewCaches(ctx, &kubeClient, false)
 	if err != nil {
 		t.Fail()
 	}
@@ -222,16 +192,15 @@ func TestValidateIngress(t *testing.T) {
 		"ingress_1",
 		"ingress_1_namespace",
 		"cluster_for_ingress_1",
-		"route_for_ingress_1",
 		"internal_host_for_ingress_1",
 		"external_host_for_ingress_1",
-		&kubeClient,
 	)
 
 	translatedIngress := translatedIngress{
-		ingressName:          "ingress_2",
-		ingressNamespace:     "ingress_2_namespace",
-		routes:               []*route.Route{{Name: "route_for_ingress_2"}},
+		name: types.NamespacedName{
+			Namespace: "ingress_2_namespace",
+			Name:      "ingress_2",
+		},
 		clusters:             []*v2.Cluster{{Name: "cluster_for_ingress_2"}},
 		externalVirtualHosts: []*route.VirtualHost{{Name: "external_host_for_ingress_2", Domains: []string{"external_host_for_ingress_2"}}},
 		//This domain should clash with the cached ingress.
@@ -242,7 +211,7 @@ func TestValidateIngress(t *testing.T) {
 	assert.Error(t, err, ErrDomainConflict.Error())
 }
 
-func getVHostsNames(routeConfigs []v2.RouteConfiguration) ([]string, error) {
+func getVHostsNames(routeConfigs []*v2.RouteConfiguration) []string {
 	var res []string
 
 	for _, routeConfig := range routeConfigs {
@@ -251,79 +220,5 @@ func getVHostsNames(routeConfigs []v2.RouteConfiguration) ([]string, error) {
 		}
 	}
 
-	return res, nil
-}
-
-func TestCacheWithWarmingWithoutIngressesToSync(t *testing.T) {
-	logger := zap.S()
-	kubeClient := fake.Clientset{}
-	ctx := context.Background()
-
-	var ingressesToSync []*v1alpha1.Ingress
-	caches, err := NewCaches(ctx, logger, &kubeClient, false, ingressesToSync)
-	if err != nil {
-		t.Fail()
-	}
-
-	// If caches are not synced, let's fail as this should return false.
-	if !caches.hasSynced() {
-		t.Fail()
-	}
-
-	// WaitForSync channel should be closed.
-	select {
-	case <-caches.WaitForSync():
-		return
-	default:
-		t.Fail()
-	}
-}
-
-func TestCacheWithWarmingWithIngressesToSync(t *testing.T) {
-	logger := zap.S()
-	kubeClient := fake.Clientset{}
-	ctx := context.Background()
-
-	ingressesToSync := []*v1alpha1.Ingress{
-		{
-			TypeMeta:   v1.TypeMeta{},
-			ObjectMeta: v1.ObjectMeta{Name: "test1", Namespace: "namespace1"},
-			Spec:       v1alpha1.IngressSpec{},
-			Status:     v1alpha1.IngressStatus{},
-		},
-	}
-	caches, err := NewCaches(ctx, logger, &kubeClient, false, ingressesToSync)
-	if err != nil {
-		t.Fail()
-	}
-
-	// If caches are synced, let's fail, as this should return false.
-	if caches.hasSynced() {
-		t.Fail()
-	}
-
-	// WaitForSync should still be open.
-	select {
-	case <-caches.WaitForSync():
-		t.Fail()
-	default:
-		// This means the channel has no data and it's still open, this is good, let's continue.
-		break
-	}
-
-	caches.deleteFromSyncList("test1", "namespace1")
-
-	// If caches are not synced, let's fail as this should return false.
-	if !caches.hasSynced() {
-		t.Fail()
-	}
-
-	// Let's check for the sync channel to be closed.
-	select {
-	case <-caches.WaitForSync():
-		return
-	default:
-		// Let's fail as the channel has not been closed.
-		t.Fail()
-	}
+	return res
 }
