@@ -28,7 +28,7 @@ import (
 	kubeclient "k8s.io/client-go/kubernetes"
 
 	"knative.dev/net-kourier/pkg/config"
-	"knative.dev/net-kourier/pkg/envoy"
+	envoy "knative.dev/net-kourier/pkg/envoy/api"
 	"knative.dev/networking/pkg/apis/networking/v1alpha1"
 	"knative.dev/networking/pkg/ingress"
 )
@@ -44,7 +44,7 @@ const (
 
 // For now, when updating the info for an ingress we delete it, and then
 // regenerate it. We can optimize this later.
-func UpdateInfoForIngress(ctx context.Context, caches *Caches, ing *v1alpha1.Ingress, kubeclient kubeclient.Interface, translator *IngressTranslator, extAuthzEnabled bool) error {
+func UpdateInfoForIngress(ctx context.Context, caches *Caches, ing *v1alpha1.Ingress, translator *IngressTranslator, extAuthzEnabled bool) error {
 	// Adds a header with the ingress Hash and a random value header to force the config reload.
 	_, err := ingress.InsertProbe(ing)
 	if err != nil {
@@ -60,76 +60,48 @@ func UpdateInfoForIngress(ctx context.Context, caches *Caches, ing *v1alpha1.Ing
 		return nil
 	}
 
-	return caches.UpdateIngress(ctx, ing, ingressTranslation, kubeclient)
+	return caches.UpdateIngress(ctx, ingressTranslation)
 }
 
-func listenersFromVirtualHosts(ctx context.Context, externalVirtualHosts []*route.VirtualHost,
+func listenersFromVirtualHosts(
+	ctx context.Context,
+	externalVirtualHosts []*route.VirtualHost,
 	clusterLocalVirtualHosts []*route.VirtualHost,
 	sniMatches []*envoy.SNIMatch,
-	kubeclient kubeclient.Interface, caches *Caches) ([]*v2.Listener, error) {
+	kubeclient kubeclient.Interface,
+	caches *Caches) ([]*v2.Listener, error) {
 
-	var listeners []*v2.Listener
+	// First, we save the RouteConfigs with the proper name and all the virtualhosts etc. into the cache.
+	externalRouteConfig := envoy.NewRouteConfig(externalRouteConfigName, externalVirtualHosts)
+	internalRouteConfig := envoy.NewRouteConfig(internalRouteConfigName, clusterLocalVirtualHosts)
+	caches.routeConfig = []*v2.RouteConfiguration{externalRouteConfig, internalRouteConfig}
 
-	externalManager := envoy.NewHTTPConnectionManager(externalVirtualHosts)
-	internalManager := envoy.NewHTTPConnectionManager(clusterLocalVirtualHosts)
-
-	internalRouteConfig := internalManager.GetRouteConfig()
-	externalRouteConfig := externalManager.GetRouteConfig()
-
-	// We need to keep these for the case of HTTPS with SNI routing
-	originalExternalManager := externalManager
-	originalExternalVHosts := externalRouteConfig.VirtualHosts
-
-	// Set proper names so those can be referred later.
-	internalRouteConfig.Name = internalRouteConfigName
-	externalRouteConfig.Name = externalRouteConfigName
-
-	// Now we save the RouteConfigs with the proper name and all the virtualhosts etc.. into the cache.
-	caches.routeConfig = []v2.RouteConfiguration{}
-	caches.routeConfig = append(caches.routeConfig, *externalRouteConfig)
-	caches.routeConfig = append(caches.routeConfig, *internalRouteConfig)
-
-	// Now let's forget about the cache, and override the internal manager to point to the RDS and look for the proper
-	// names.
-	internalRDSHTTPConnectionManager := envoy.NewRDSHTTPConnectionManager(internalRouteConfigName)
-	internalManager.RouteSpecifier = &internalRDSHTTPConnectionManager
-
-	// Set the discovery to ADS
-	externalRDSHTTPConnectionManager := envoy.NewRDSHTTPConnectionManager(externalRouteConfigName)
-	externalManager.RouteSpecifier = &externalRDSHTTPConnectionManager
-
-	// CleanUp virtual hosts.
-	externalRouteConfig.VirtualHosts = []*route.VirtualHost{}
-	internalRouteConfig.VirtualHosts = []*route.VirtualHost{}
-
-	externalHTTPEnvoyListener, err := newExternalHTTPEnvoyListener(&externalManager)
+	// Now we setup connection managers, that reference the routeconfigs via RDS.
+	externalManager := envoy.NewHTTPConnectionManager(externalRouteConfig.Name)
+	internalManager := envoy.NewHTTPConnectionManager(internalRouteConfig.Name)
+	externalHTTPEnvoyListener, err := envoy.NewHTTPListener(externalManager, config.HTTPPortExternal)
 	if err != nil {
 		return nil, err
 	}
-	listeners = append(listeners, externalHTTPEnvoyListener)
-
-	internalEnvoyListener, err := newInternalEnvoyListener(&internalManager)
+	internalEnvoyListener, err := envoy.NewHTTPListener(internalManager, config.HTTPPortInternal)
 	if err != nil {
 		return nil, err
 	}
-	listeners = append(listeners, internalEnvoyListener)
+
+	listeners := []*v2.Listener{externalHTTPEnvoyListener, internalEnvoyListener}
 
 	// Configure TLS Listener. If there's at least one ingress that contains the
 	// TLS field, that takes precedence. If there is not, TLS will be configured
 	// using a single cert for all the services if the creds are given via ENV.
 	if len(sniMatches) > 0 {
-		// TODO: Can we make this work with "HttpConnectionManager_Rds"?
-		externalRouteConfig.VirtualHosts = originalExternalVHosts
-		externalHTTPSEnvoyListener, err := newExternalHTTPSEnvoyListener(
-			&originalExternalManager, sniMatches,
-		)
+		externalHTTPSEnvoyListener, err := envoy.NewHTTPSListenerWithSNI(externalManager, config.HTTPSPortExternal, sniMatches)
 		if err != nil {
 			return nil, err
 		}
 		listeners = append(listeners, externalHTTPSEnvoyListener)
 	} else if useHTTPSListenerWithOneCert() {
 		externalHTTPSEnvoyListener, err := newExternalEnvoyListenerWithOneCert(
-			ctx, &externalManager, kubeclient,
+			ctx, externalManager, kubeclient,
 		)
 		if err != nil {
 			return nil, err
@@ -147,39 +119,22 @@ func useHTTPSListenerWithOneCert() bool {
 		os.Getenv(envCertsSecretName) != ""
 }
 
-func sslCreds(ctx context.Context, kubeClient kubeclient.Interface, secretNamespace string, secretName string) (certificateChain string, privateKey string, err error) {
+func sslCreds(ctx context.Context, kubeClient kubeclient.Interface, secretNamespace string, secretName string) (certificateChain []byte, privateKey []byte, err error) {
 	secret, err := kubeClient.CoreV1().Secrets(secretNamespace).Get(ctx, secretName, metav1.GetOptions{})
-
 	if err != nil {
-		return "", "", err
+		return nil, nil, err
 	}
 
-	certificateChain = string(secret.Data[certFieldInSecret])
-	privateKey = string(secret.Data[keyFieldInSecret])
-
-	return certificateChain, privateKey, nil
+	return secret.Data[certFieldInSecret], secret.Data[keyFieldInSecret], nil
 }
 
 func newExternalEnvoyListenerWithOneCert(ctx context.Context, manager *httpconnmanagerv2.HttpConnectionManager, kubeClient kubeclient.Interface) (*v2.Listener, error) {
 	certificateChain, privateKey, err := sslCreds(
 		ctx, kubeClient, os.Getenv(envCertsSecretNamespace), os.Getenv(envCertsSecretName),
 	)
-
 	if err != nil {
 		return nil, err
 	}
 
 	return envoy.NewHTTPSListener(manager, config.HTTPSPortExternal, certificateChain, privateKey)
 }
-
-func newExternalHTTPEnvoyListener(manager *httpconnmanagerv2.HttpConnectionManager) (*v2.Listener, error) {
-	return envoy.NewHTTPListener(manager, config.HTTPPortExternal)
-}
-
-func newInternalEnvoyListener(manager *httpconnmanagerv2.HttpConnectionManager) (*v2.Listener, error) {
-	return envoy.NewHTTPListener(manager, config.HTTPPortInternal)
-}
-
-func newExternalHTTPSEnvoyListener(manager *httpconnmanagerv2.HttpConnectionManager, sniMatches []*envoy.SNIMatch) (*v2.Listener, error) {
-	return envoy.NewHTTPSListenerWithSNI(manager, config.HTTPSPortExternal, sniMatches)
-}
