@@ -21,24 +21,19 @@ import (
 	"errors"
 	"fmt"
 
+	"github.com/envoyproxy/go-control-plane/pkg/cache"
 	"knative.dev/net-kourier/pkg/config"
-
-	kubeclient "k8s.io/client-go/kubernetes"
-
+	envoy "knative.dev/net-kourier/pkg/envoy/server"
+	"knative.dev/net-kourier/pkg/generator"
 	"knative.dev/networking/pkg/apis/networking/v1alpha1"
 	"knative.dev/networking/pkg/client/injection/reconciler/networking/v1alpha1/ingress"
 	"knative.dev/networking/pkg/status"
 	"knative.dev/pkg/logging"
 	"knative.dev/pkg/reconciler"
-
-	"knative.dev/net-kourier/pkg/envoy"
-	"knative.dev/net-kourier/pkg/generator"
-	"knative.dev/net-kourier/pkg/knative"
 )
 
 type Reconciler struct {
 	xdsServer         *envoy.XdsServer
-	kubeClient        kubeclient.Interface
 	caches            *generator.Caches
 	statusManager     *status.Prober
 	ingressTranslator *generator.IngressTranslator
@@ -70,7 +65,12 @@ func (r *Reconciler) ReconcileKind(ctx context.Context, ing *v1alpha1.Ingress) r
 			return fmt.Errorf("failed to probe Ingress %s/%s: %w", ing.GetNamespace(), ing.GetName(), err)
 		}
 		if ready {
-			knative.MarkIngressReady(ing)
+			external, internal := config.ServiceHostnames()
+			ing.Status.MarkLoadBalancerReady(
+				[]v1alpha1.LoadBalancerIngressStatus{{DomainInternal: external}},
+				[]v1alpha1.LoadBalancerIngressStatus{{DomainInternal: internal}},
+			)
+			ing.Status.MarkNetworkConfigured()
 		} else {
 			ing.Status.MarkLoadBalancerNotReady()
 		}
@@ -98,20 +98,15 @@ func (r *Reconciler) FinalizeKind(ctx context.Context, ing *v1alpha1.Ingress) re
 }
 func (r *Reconciler) ObserveFinalizeKind(ctx context.Context, ing *v1alpha1.Ingress) reconciler.Event {
 	logger := logging.FromContext(ctx)
-	logger.Infof("Deleting Ingress %s namespace: %s", ing.Name, ing.Namespace)
-	ingress := r.caches.GetIngress(ing.Name, ing.Namespace)
+	logger.Infof("Deleting Ingress %s/%s", ing.Name, ing.Namespace)
 
-	// We need to check for ingress not being nil, because we can receive an event from an already
-	// removed ingress, like for example, when the endpoints object for that ingress is updated/removed.
-	if ingress != nil {
-		r.statusManager.CancelIngressProbing(ingress)
-	}
+	r.statusManager.CancelIngressProbing(ing)
 
-	if err := r.caches.DeleteIngressInfo(ctx, ing.Name, ing.Namespace, r.kubeClient); err != nil {
+	if err := r.caches.DeleteIngressInfo(ctx, ing.Name, ing.Namespace); err != nil {
 		return err
 	}
 
-	return r.updateEnvoyConfig()
+	return r.updateEnvoyConfig(ctx)
 }
 
 func (r *Reconciler) updateIngress(ctx context.Context, ingress *v1alpha1.Ingress) error {
@@ -119,23 +114,26 @@ func (r *Reconciler) updateIngress(ctx context.Context, ingress *v1alpha1.Ingres
 	logger.Infof("Updating Ingress %s namespace: %s", ingress.Name, ingress.Namespace)
 
 	if err := generator.UpdateInfoForIngress(
-		ctx, r.caches, ingress, r.kubeClient, r.ingressTranslator, r.extAuthz,
-	); err != nil {
+		ctx, r.caches, ingress, r.ingressTranslator, r.extAuthz); err != nil {
 		return err
 	}
 
-	if err := r.updateEnvoyConfig(); err != nil {
+	if err := r.updateEnvoyConfig(ctx); err != nil {
 		return err
 	}
 
 	return nil
 }
 
-func (r *Reconciler) updateEnvoyConfig() error {
+func (r *Reconciler) updateEnvoyConfig(ctx context.Context) error {
+	logger := logging.FromContext(ctx)
+
 	currentSnapshot, err := r.xdsServer.GetSnapshot(config.EnvoyNodeID)
 	if err != nil {
 		return err
 	}
+
+	logger.Debugf("Preparing Envoy Snapshot")
 	newSnapshot, err := r.caches.ToEnvoySnapshot()
 	if err != nil {
 		return err
@@ -143,7 +141,7 @@ func (r *Reconciler) updateEnvoyConfig() error {
 
 	// Let's warm the Clusters first, by sending the previous snapshot with the new cluster list, that includes
 	// both new and old clusters.
-	currentSnapshot.Clusters = newSnapshot.Clusters
+	currentSnapshot.Resources[cache.Cluster].Items = newSnapshot.GetResources(cache.ClusterType)
 
 	//Validate that the snapshot is consistent.
 	if err := currentSnapshot.Consistent(); err != nil {
