@@ -23,7 +23,7 @@ failed=0
 
 go_test_e2e -timeout=20m -parallel=12 \
   ./test/conformance \
-  --enable-beta \
+  --enable-alpha --enable-beta \
   --ingressClass=kourier.ingress.networking.knative.dev || failed=1
 
 # Give the controller time to sync with the rest of the system components.
